@@ -81,7 +81,10 @@ class NoseGAE(Plugin):
             fix_sys_path() # wipes out sys.path
             sys.path.extend(saved_path) # put back our previous path
             
-            from google.appengine.tools import dev_appserver
+            try:
+                from google.appengine.tools import dev_appserver
+            except ImportError:
+                from google.appengine.tools import old_dev_appserver as dev_appserver
             from google.appengine.tools.dev_appserver_main import \
                 DEFAULT_ARGS, ARG_CLEAR_DATASTORE, ARG_LOG_LEVEL, \
                 ARG_DATASTORE_PATH, ARG_HISTORY_PATH
@@ -128,6 +131,11 @@ class NoseGAE(Plugin):
         dev_appserver = self._gae['dev_appserver']
         gae_opts = args.copy()
         gae_opts["root_path"] = self._path
+
+        gae_opts["use_sqlite"] = True
+        gae_opts["skip_sdk_update_check"] = True
+        gae_opts["disable_console"] = True
+        gae_opts["high_replication"] = True
         gae_opts[clear] = self._temp_data
         gae_opts[ds_path] = self._data_path
         gae_opts[hs_path] = os.path.join(tempfile.gettempdir(),
